AshAuthentication.Phoenix.SignOutLive (ash_authentication_phoenix v2.16.0)

A generic, white-label sign-out confirmation page.

This live-view can be rendered into your app using the AshAuthentication.Phoenix.Router.sign_out_route/3 macro in your router.

It displays a confirmation form that submits a DELETE request to the sign-out controller action, ensuring CSRF protection.

Overrides

This component provides the following overrides:

  • :root_class - CSS class for the root div element.

See AshAuthentication.Phoenix.Overrides for more information.