AshAuthentication.Phoenix.Components.Flash (ash_authentication_phoenix v2.15.0)
View SourceRenders the Phoenix flash messages set by Ash Authentication Phoenix.
Overrides
This component provides the following overrides:
:message_class_info- CSS class for the messagedivelement when the flash key is:info.:message_class_error- CSS class for the messagedivelement when the flash key is:error.
See AshAuthentication.Phoenix.Overrides for more information.
Props
* `overrides` - A list of override modules.
Summary
Types
@type props() :: %{optional(:overrides) => [module()]}